package org.artifactory.metrics.framework;

import org.artifactory.spring.ReloadableBean;
import org.jfrog.metrics.model.TrackingSchema;

import java.util.Map;

/**
 * A service to perform Feature Adoption (aka Usage Metrics) tracking operations.
 *
 * @author Oleksandr Legenkiy
 */
public interface FeatureAdoptionService extends ReloadableBean {

    /**
     * This is a basic method that should be used to track usage of features as part of Feature Adoption.
     *
     * @param feature a feature that should be tracked
     * @param action  an action that should be tracked
     * @param success <code>true</code> if a tracked action was successful, otherwise <code>false</code>
     * @param labels  a map of dynamic labels and their values to be logged
     */
    void trackAdoption(FeatureAdoptionFeature feature, FeatureAdoptionAction action, boolean success,
                       Map<String, String> labels);

    void trackIncrease(TrackingSchema trackingSample);

    void trackDecrease(TrackingSchema trackingSample);

    void trackAverage(TrackingSchema trackingSample);

    void trackSet(TrackingSchema trackingSample);

    void trackUnset(TrackingSchema trackingSample);
}
