package org.artifactory.queue.services;

import lombok.NonNull;
import org.artifactory.event.queue.QueueCursorType;
import org.artifactory.event.queue.QueueStatus;
import org.artifactory.storage.db.event.model.NodeEventCursor;

import javax.annotation.Nonnull;

/**
 * A "bridge" service interface between Events services and PersistentQueue framework
 * contains all the methods needed to handle the cursor.
 *
 * @author avishayh
 */
public interface PersistentQueueCursorService {

    /**
     * will update cursors marker and last_updated
     *  @param cursorName
     * @param newMarker*/
    void updateCursor(@Nonnull String cursorName, long newMarker);
    /**
     * update cursor with marker
     *
     * @param cursorName
     * @param marker
     * @param timestamp in case of old timestamp cursor's 'last_updated' wont be updated
     */
    void updateMarkerByTimestamp(@Nonnull String cursorName, long marker, long timestamp);

    void resetMarker(String repoKey, String cursorName);

    void deleteMarker(String cursorName);

    /**
     * @param cursorName - name of cursor
     * @param type       - type of cursor if need to create one
     * @return the current marker (eventId) for a cursor, if cursor doesn't exist creates one with initial value.
     */
    NodeEventCursor getCursorAndCreateIfNeeded(@Nonnull String cursorName,
            @Nonnull QueueCursorType type);

    QueueStatus getStatus(String repoKey, String cursorName);

    /**
     * Create cursor marker if not exists
     */
    void createMarkerIfNotExists(String repoKey, String cursorName, QueueCursorType type);

    void updateCursorAsOutOfSync(@NonNull String cursorName);

    void updateCursorAsSynced(@Nonnull String cursorName);

    long getCachedLatestEventId();
}
