package org.artifactory.traffic.v2;

import org.artifactory.security.access.AccessTokenAuthentication;
import org.artifactory.traffic.entry.DownloadEntry;
import org.artifactory.traffic.entry.RedirectEntry;
import org.artifactory.traffic.entry.TransferEntry;
import org.artifactory.traffic.entry.UploadEntry;
import org.jfrog.access.token.JwtAccessToken;
import org.testng.annotations.DataProvider;
import org.testng.annotations.Test;

import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertTrue;

public class TrafficEntryV2Test {

    @DataProvider
    public static Object[][] entries() {
        return new Object[][] {
                {
                        new DownloadEntry("repoPath", 48, 5,
                                "userAddress", "userIdenifier"),
                        "|DOWNLOAD|USER||userAddress|repoPath|48|48|48"
                },
                {
                        new RedirectEntry("repoPath2", 49, 6,
                                "userAddress2"),
                        "|REDIRECT|USER||userAddress2|repoPath2|49|49|49"
                },
                {
                        new UploadEntry("repoPath3", 50, 7,
                                "userAddress3"),
                        "|UPLOAD|USER||userAddress3|repoPath3|50|50|50"
                },
                {
                        new DownloadEntry("repoPath4", 51, 8,
                                "userAddress4", "userxray"),
                        "|DOWNLOAD|XRAY||userAddress4|repoPath4|51|51|51"
                }
        };
    }

    @Test(dataProvider = "entries")
    public void test(TransferEntry entry, String expected) {
        TrafficEntryV2 trafficEntryV2 = TrafficEntryV2.map(entry, null);
        String string = trafficEntryV2.toString();
        assertTrue(string.endsWith(expected));
    }

    @DataProvider
    public static Object[][] entriesWithAuth() {
        return new Object[][] {
                {
                        new DownloadEntry("repoPath4", 51, 8,
                                "userAddress4", "userxray"),
                        "jfxr@cve_applicability_12345678",
                        "|DOWNLOAD|XRAY_REPETITIVE||userAddress4|repoPath4|51|51|51"
                },
                {
                        new DownloadEntry("repoPath4", 51, 8,
                                "userAddress4", "userxray"),
                        "jfxr@extra_analysis_12345678",
                        "|DOWNLOAD|XRAY_REPETITIVE||userAddress4|repoPath4|51|51|51"
                }
        };
    }

    @Test(dataProvider = "entriesWithAuth")
    public void testWithAuth(TransferEntry entry, String subject, String expected) {
        AccessTokenAuthentication authentication = mock(AccessTokenAuthentication.class);
        JwtAccessToken token = mock(JwtAccessToken.class);
        when(token.getSubject()).thenReturn(subject);
        when(authentication.getAccessToken()).thenReturn(token);
        TrafficEntryV2 trafficEntryV2 = TrafficEntryV2.map(entry, authentication);
        String string = trafficEntryV2.toString();
        assertTrue(string.endsWith(expected));
    }
}
