package org.artifactory.ui.utils;

import org.artifactory.descriptor.repo.RepoType;
import org.artifactory.fs.ItemInfo;
import org.artifactory.model.xstream.fs.FileInfoImpl;
import org.artifactory.repo.RepoPathFactory;
import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

import java.util.List;

class BrowseUtilsTest {

    @Test
    void testFilterItemsIfNeeded() {
        List<ItemInfo> items = List.of(
                new FileInfoImpl(RepoPathFactory.create("repo", "")),
                new FileInfoImpl(RepoPathFactory.create("repo", ".git")),
                new FileInfoImpl(RepoPathFactory.create("repo", ".git/yo")),
                new FileInfoImpl(RepoPathFactory.create("repo", ".got/yo")),
                new FileInfoImpl(RepoPathFactory.create("repo", "git/yo")),
                new FileInfoImpl(RepoPathFactory.create("repo", "git")),
                new FileInfoImpl(RepoPathFactory.create("repo", "a.sha1")),
                new FileInfoImpl(RepoPathFactory.create("repo", "a.sha256")),
                new FileInfoImpl(RepoPathFactory.create("repo", "a.md5"))
        );

        List<ItemInfo> nonCargoResults = BrowseUtils.filterItemsIfNeeded(items, null);
        Assertions.assertEquals(6, nonCargoResults.size());

        List<ItemInfo> cargoResults = BrowseUtils.filterItemsIfNeeded(items, RepoType.Cargo);
        Assertions.assertEquals(4, cargoResults.size());
        cargoResults.forEach(item -> Assertions.assertFalse(item.getRelPath().startsWith(".git")));
    }

}