package org.artifactory.rest.resource.system;

import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpStatus;
import org.artifactory.api.rest.constant.SystemRestConstants;
import org.artifactory.probes.model.ProbesError;
import org.artifactory.probes.service.ProbesService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

import javax.ws.rs.GET;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import javax.ws.rs.QueryParam;
import javax.ws.rs.ServiceUnavailableException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;

/**
 * @author Andrey Tashlitsky
 */
@Slf4j
@Component
@Path("v1/" + SystemRestConstants.PATH_ROOT)
public class ProbesResource {

    private static final String OK = "OK\n";
    private static final String UNAVAILABLE = "UNAVAILABLE";

    private final ProbesService probesService;

    @Autowired
    public ProbesResource(ProbesService probesService) {
        this.probesService = probesService;
    }

    @GET
    @Path(SystemRestConstants.PATH_READINESS)
    @Produces(MediaType.APPLICATION_JSON)
    public Response readiness(@QueryParam("noCache") boolean noCache) {
        try {
            log.trace("Received a readiness probe, noCache={}", noCache);
            probesService.checkReadinessStatus(noCache);
            return Response.ok().entity(OK).build();
        } catch (ServiceUnavailableException e) {
            log.trace("Readiness probe has failed: {} ", e.getMessage(), e);
            return Response.status(HttpStatus.SC_SERVICE_UNAVAILABLE)
                    .entity(ProbesError.builder().code(UNAVAILABLE).message(e.getMessage()).build())
                    .build();
        }
    }

    @GET
    @Path(SystemRestConstants.PATH_LIVENESS)
    @Produces(MediaType.APPLICATION_JSON)
    public Response liveness() {
        try {
            log.trace("Received a liveness probe");
            probesService.checkLivenessStatus();
            return Response.ok().entity(OK).build();
        } catch (ServiceUnavailableException e) {
            log.trace("Liveness probe has failed: {} ", e.getMessage(), e);
            return Response.status(HttpStatus.SC_SERVICE_UNAVAILABLE)
                    .entity(ProbesError.builder().code(UNAVAILABLE).message(e.getMessage()).build())
                    .build();
        }
    }
}
