package org.artifactory.rest.services.retention;

import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.retention.ArtifactRetentionAddon;
import org.artifactory.addon.retention.ArtifactRetentionPolicyBaseModel;
import org.artifactory.addon.retention.PolicyTranslator;
import org.artifactory.descriptor.retention.ArtifactRetentionPolicyDescriptor;
import org.artifactory.metrics.framework.FeatureAdoptionAction;
import org.artifactory.metrics.framework.FeatureAdoptionFeature;
import org.artifactory.metrics.framework.FeatureAdoptionService;
import org.artifactory.rest.common.service.ArtifactoryRestRequest;
import org.artifactory.rest.common.service.RestResponse;
import org.artifactory.rest.common.service.RestService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Component;

import javax.servlet.http.HttpServletResponse;
import java.util.Map;

import static org.artifactory.descriptor.retention.ArtifactRetentionOperationType.ARCHIVE;

/**
 * @author Omri Ziv
 */
@Component
@Scope(BeanDefinition.SCOPE_PROTOTYPE)
public class CreateArtifactRetentionPolicyService implements RestService<ArtifactRetentionPolicyBaseModel> {

    private final AddonsManager addonsManager;
    private final FeatureAdoptionService faService;

    @Autowired
    public CreateArtifactRetentionPolicyService(AddonsManager addonsManager, FeatureAdoptionService faService) {
        this.addonsManager = addonsManager;
        this.faService = faService;
    }

    @Override
    public void execute(ArtifactoryRestRequest<ArtifactRetentionPolicyBaseModel> request, RestResponse response) {
        Map<String, String> dynamicLabels = Map.of("entity", "archiving_policy", "ui", "true", "admin", "true");
        try {
            ArtifactRetentionPolicyBaseModel policyModelBase = request.getImodel();
            String policyKey = policyModelBase.getKey();
            ArtifactRetentionPolicyDescriptor
                    policyDescriptor = PolicyTranslator.toPolicyDescriptor(policyModelBase, ARCHIVE);
            ArtifactRetentionPolicyBaseModel policyRetrieved = addonsManager.addonByType(ArtifactRetentionAddon.class)
                    .addPolicy(policyKey, policyDescriptor);
            response.info("Successfully added retention policy " + policyRetrieved.getKey());
            faService.trackAdoption(FeatureAdoptionFeature.COLD_STORAGE,
                    FeatureAdoptionAction.CREATED, true, dynamicLabels);
            response.responseCode(HttpServletResponse.SC_CREATED);
        } catch (Exception e) {
            faService.trackAdoption(FeatureAdoptionFeature.COLD_STORAGE,
                    FeatureAdoptionAction.CREATED, false, dynamicLabels);
            throw e;
        }
    }
}
