package org.artifactory.rest.resource.archive;

import org.artifactory.addon.AddonsManager;
import org.artifactory.addon.rest.RestAddon;
import org.artifactory.api.build.BuildService;
import org.artifactory.api.rest.build.artifacts.BuildArtifactsRequest;
import org.artifactory.test.ArtifactoryHomeBoundTest;
import org.artifactory.traffic.TrafficService;
import org.artifactory.traffic.v2.TrafficEntryV2;
import org.glassfish.jersey.server.CloseableService;
import org.mockito.ArgumentCaptor;
import org.testng.annotations.Test;

import javax.ws.rs.core.Response;
import javax.ws.rs.core.StreamingOutput;
import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.times;
import static org.mockito.Mockito.verify;
import static org.mockito.Mockito.when;
import static org.testng.Assert.assertEquals;

public class ArchiveResourceTest extends ArtifactoryHomeBoundTest {

    @Test
    public void smoke() throws IOException {
        AddonsManager addonsManager = mock(AddonsManager.class);
        RestAddon restAddon = mock(RestAddon.class);
        File file = mock(File.class);
        when(file.length()).thenReturn(48L);
        when(restAddon.getBuildArtifactsArchive(any())).thenReturn(file);
        when(addonsManager.addonByType(RestAddon.class)).thenReturn(restAddon);
        CloseableService closeableService = mock(CloseableService.class);
        ArchiveResource resource = new ArchiveResourceForTest();
        BuildService buildService = mock(BuildService.class);
        when(buildService.getPreferredBuildRepo(any(), any())).thenReturn("build-repo");
        TrafficService trafficService = mock(TrafficService.class);
        resource.setAddonsManager(addonsManager);
        resource.setCloseableService(closeableService);
        resource.setBuildService(buildService);
        resource.setTrafficService(trafficService);

        BuildArtifactsRequest request = new BuildArtifactsRequest();
        request.setBuildName("build-name");
        request.setBuildNumber("build-number");
        request.setArchiveType("zip");

        Response response = resource.getBuildArtifactsArchive(request);

        ByteArrayOutputStream baos = new ByteArrayOutputStream();
        ((StreamingOutput) response.getEntity()).write(baos);

        ArgumentCaptor<TrafficEntryV2> trafficEntryV2Captor = ArgumentCaptor.forClass(TrafficEntryV2.class);
        verify(trafficService, times(1)).handleTrafficEntry(trafficEntryV2Captor.capture());
        TrafficEntryV2 captured = trafficEntryV2Captor.getValue();

        assertEquals(captured.getAction(), TrafficEntryV2.TrafficAction.DOWNLOAD);
        assertEquals(captured.getActor(), TrafficEntryV2.TrafficActor.USER);
        assertEquals(captured.getRedirectTarget(), TrafficEntryV2.TrafficTarget.DIRECT);
        assertEquals(captured.getUserAddress(), "");
        assertEquals(captured.getRepoPath(), "build-repo:build-name");
        assertEquals(captured.getSize(), 48);
        assertEquals(captured.getRequestedSize(), 48);
        assertEquals(captured.getTransferredSize(), 9);
    }

    private static class ArchiveResourceForTest extends ArchiveResource {
        @Override
        InputStream getArchiveStream(File buildArtifactsArchive) throws FileNotFoundException {
            return new ByteArrayInputStream("test-data".getBytes());
        }
    }
}